#
# spec file for package alacritty
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define rev dcc4b750381cd2096b6001cbf94e95a6e6b52ed0
Name:           alacritty
Version:        0.1.0
Release:        lp151.3.52
Summary:        A GPU-accelerated terminal emulator
License:        Apache-2.0
Group:          System/X11/Terminals
URL:            https://github.com/jwilm/alacritty/
Source:         https://github.com/jwilm/alacritty/archive/%{rev}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  cargo
BuildRequires:  cmake
BuildRequires:  fontconfig-devel
BuildRequires:  freetype-devel
BuildRequires:  rust
BuildRequires:  rust-std
BuildRequires:  xclip

%description
Alacritty is a terminal emulator written in Rust that leverages the GPU for
rendering.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/X11/Terminals
Requires:       bash-completion
Supplements:    packageand(%{name}:bash)
BuildArch:      noarch

%description bash-completion
The official bash completion script for alacritty. It includes support
for every argument that can currently be passed to alacritty.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/X11/Terminals
Supplements:    packageand(%{name}:fish)
BuildArch:      noarch

%description fish-completion
The official fish completion script for alacritty.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          System/X11/Terminals
Supplements:    packageand(%{name}:zsh)
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for alacritty.

%prep
%setup -q -n %{name}-%{rev} -a1
mkdir cargo-home
cat >cargo-home/config <<EOF
[source.crates-io]
replace-with = "vendored-sources"

[source."https://github.com/jwilm/libfontconfig"]
git = "https://github.com/jwilm/libfontconfig"
branch = "updated-2017-10-8"
replace-with = "vendored-sources"

[source."https://github.com/jwilm/rust-fontconfig"]
git = "https://github.com/jwilm/rust-fontconfig"
branch = "updated-2017-10-8"
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "./vendor"
EOF
%ifarch aarch64 ppc64le
# Remove checksum of config.guess and config.sub since aarch64 and ppc64le modify them
sed -i 's#"expat/conftools/config.guess":"ebaffe1c6683ae2c3dcabb87825a83b892f00391514756f7640c4a3dcafbad4f",##g' ./vendor/expat-sys/.cargo-checksum.json
sed -i 's#"expat/conftools/config.sub":"523cb028db907d1fbbcecdcac6737f9e2eeba48fb639231dbc5ae69238f276c9",##g' ./vendor/expat-sys/.cargo-checksum.json
%endif

%build
export CARGO_HOME=$PWD/cargo-home
cargo build --release %{?_smp_mflags}

%install
export CARGO_HOME=$PWD/cargo-home
cargo install --root=%{buildroot}/%{_prefix}

# rm duplicate license and useless toml file
rm -fr %{buildroot}%{_datadir}
rm  %{buildroot}%{_prefix}/.crates.toml

# install man page and completions
install -Dm 0644 %{name}.man %{buildroot}/%{_mandir}/man1/%{name}.1
install -Dm 0644 %{name}-completions.bash %{buildroot}/%{_datadir}/bash-completion/completions/%{name}
install -Dm 0644 %{name}-completions.fish %{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -Dm 0644 %{name}-completions.zsh  %{buildroot}/%{_datadir}/zsh/site-functions/_%{name}

%files
%license LICENSE-APACHE
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh

%changelog
* Wed Apr 25 2018 guillaume.gardet@opensuse.org
- Remove checksums for config.guess and config.sub for aarch64
  and ppc64le since they are updated
* Fri Mar 30 2018 avindra@opensuse.org
- Drop unneeded Requires for fish and zsh completions
* Wed Mar 28 2018 jengelh@inai.de
- Use a single %%setup call.
- Trim filler wording from description.
* Fri Mar 23 2018 avindra@opensuse.org
- update to rev dcc4b750381cd2096b6001cbf94e95a6e6b52ed0
  * fix verbose logging (-v, -vv and -vvv)
* Sun Mar 18 2018 avindra@opensuse.org
- update to rev 6debc4f3351446417d0c4e38173cd9ef0faa71d5
  * fish shell completions
  * enable SRGB support
  * extend SGR and VT200 mouse support
  * switch meta key to alt instead of super
* Tue Mar 13 2018 avindra@opensuse.org
- initial package @ cb05e72be2fcf7e78bff99e4316f19510bf4f502
